---
title: <span class="badge builder"></span> ReduceDataOptions
---
# <span class="badge builder"></span> ReduceDataOptions

## Constructor

```python
ReduceDataOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.ReduceDataOptions
```

### <span class="badge object-method"></span> calcs

When !values, pick one value for the whole field

```python
def calcs(calcs: list[str]) -> typing.Self
```

### <span class="badge object-method"></span> fields

Which fields to show.  By default this is only numeric fields

```python
def fields(fields: str) -> typing.Self
```

### <span class="badge object-method"></span> limit

if showing all values limit

```python
def limit(limit: float) -> typing.Self
```

### <span class="badge object-method"></span> values

If true show each row value

```python
def values(values: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ReduceDataOptions](./object-ReduceDataOptions.md)
